@@ -4,7 +4,8 @@ from typing import Iterable, List
 from jinja2 import Template
 from markdown import Markdown
 
-from braindead.context import add_url_to_context, build_article_context
+from braindead.constants import CONFIG
+from braindead.context import add_global_context, add_url_to_context, build_article_context
 from braindead.files import find_all_pages, find_all_posts, gather_statics, save_output
 from braindead.jinja_utils import jinja_environment, render_jinja_template
 from braindead.markdown_utils import md
@@ -14,7 +15,7 @@ def render_blog() -> None:
     """ Renders both pages and posts for the blog and moves them to dist folder."""
     started_at: float = time()
     posts: List[dict] = list(reversed(sorted(render_posts(), key=lambda x: x["date"])))
-    pages: List[str] = render_all_pages()
+    pages: List[dict] = render_all_pages()
     render_index(posts=posts)
     gather_statics()
     print(
@@ -23,18 +24,25 @@ def render_blog() -> None:
     )
 
 
-def render_all_pages() -> List[str]:
+def render_all_pages() -> List[dict]:
     """ Rendering of all the pages for the blog. markdown -> html with jinja -> html"""
     return [render_page(filename=filename, md=md) for filename in find_all_pages()]
 
 
-def render_page(filename: str, md: Markdown, additional_context: dict = None):
+def render_page(filename: str, md: Markdown, additional_context: dict = None) -> dict:
     additional_context = additional_context if additional_context else {}
     page_html: str = render_markdown_to_html(md=md, filename=filename)
-    jinja_context: dict = {"page": {"content": page_html}, **additional_context}
+    return {
+        language: _render_page(page_html, additional_context, filename, language)
+        for language in CONFIG["i18n"]["languages"]
+    }
+
+
+def _render_page(page_html: str, additional_context: dict, filename: str, language: str):
+    jinja_context: dict = add_global_context({"content": page_html, **additional_context, "language": language})
     template: Template = jinja_environment.get_template(md.Meta.get("template", ["index.html"])[0])
     output: str = render_jinja_template(template=template, context=jinja_context)
-    return save_output(original_file_name=jinja_context.get("slug", filename), output=output)
+    return save_output(original_file_name=f'{language}/{jinja_context.get("slug", filename)}', output=output)
 
 
 def render_posts() -> List[dict]:
@@ -45,7 +53,7 @@ def render_and_save_post(md: Markdown, filename: str) -> dict:
     """ Renders blog posts and saves the output as html. md -> html with jinja -> html"""
     article_html: str = render_markdown_to_html(md=md, filename=filename)
     template: Template = jinja_environment.get_template(md.Meta.get("template", "detail.html"))
-    jinja_context: dict = build_article_context(article_html=article_html, md=md)
+    jinja_context: dict = add_global_context(build_article_context(article_html=article_html, md=md))
     output: str = render_jinja_template(template=template, context=jinja_context)
     new_filename: str = save_output(original_file_name=jinja_context.get("slug", filename), output=output)
     return add_url_to_context(jinja_context=jinja_context, new_filename=new_filename)
@@ -56,8 +64,8 @@ def render_markdown_to_html(md: Markdown, filename: str) -> str:
     return md.reset().convert(open(filename).read())
 
 
-def render_index(posts: Iterable[dict]) -> str:
+def render_index(posts: Iterable[dict]) -> dict:
     md: Markdown = Markdown(extensions=["tables", "fenced_code", "codehilite", "meta", "footnotes"])
     filename = "index.md"
-    additonal_context: dict = {"articles": posts}
+    additonal_context: dict = add_global_context({"articles": posts})
     return render_page(filename=filename, md=md, additional_context=additonal_context)
